@@ -1,19 +1,22 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['luadns.com']
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-username", help="specify email address for authentication")
-    subparser.add_argument("--auth-token", help="specify token for authentication")
+    subparser.add_argument(
+        "--auth-username", help="specify email address for authentication")
+    subparser.add_argument(
+        "--auth-token", help="specify token for authentication")
+
 
 class Provider(BaseProvider):
 
@@ -26,24 +29,26 @@ class Provider(BaseProvider):
 
         payload = self._get('/zones')
 
-        domain_info = next((domain for domain in payload if domain['name'] == self.domain), None)
+        domain_info = next(
+            (domain for domain in payload if domain['name'] == self.domain), None)
 
         if not domain_info:
             raise Exception('No domain found')
 
         self.domain_id = domain_info['id']
 
-
     # Create record. If record already exists with the same content, do nothing'
+
     def create_record(self, type, name, content):
         # check if record already exists
         existing_records = self.list_records(type, name, content)
         if len(existing_records) == 1:
             return True
 
-        payload = self._post('/zones/{0}/records'.format(self.domain_id), {'type': type, 'name': self._fqdn_name(name), 'content': content, 'ttl': self._get_lexicon_option('ttl')})
+        payload = self._post('/zones/{0}/records'.format(self.domain_id), {'type': type,
+                                                                           'name': self._fqdn_name(name), 'content': content, 'ttl': self._get_lexicon_option('ttl')})
 
-        logger.debug('create_record: %s', True)
+        LOGGER.debug('create_record: %s', True)
         return True
 
     # List all records. Return an empty list if no records found
@@ -66,11 +71,13 @@ class Provider(BaseProvider):
         if type:
             records = [record for record in records if record['type'] == type]
         if name:
-            records = [record for record in records if record['name'] == self._full_name(name)]
+            records = [record for record in records if record['name']
+                       == self._full_name(name)]
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
@@ -86,10 +93,10 @@ class Provider(BaseProvider):
         if content:
             data['content'] = content
 
+        payload = self._put(
+            '/zones/{0}/records/{1}'.format(self.domain_id, identifier), data)
 
-        payload = self._put('/zones/{0}/records/{1}'.format(self.domain_id, identifier), data)
-
-        logger.debug('update_record: %s', True)
+        LOGGER.debug('update_record: %s', True)
         return True
 
     # Delete an existing record.
@@ -101,17 +108,18 @@ class Provider(BaseProvider):
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
-        
-        logger.debug('delete_records: %s', delete_record_id)
-        
-        for record_id in delete_record_id:
-            payload = self._delete('/zones/{0}/records/{1}'.format(self.domain_id, record_id))
 
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_records: %s', delete_record_id)
+
+        for record_id in delete_record_id:
+            payload = self._delete(
+                '/zones/{0}/records/{1}'.format(self.domain_id, record_id))
+
+        LOGGER.debug('delete_record: %s', True)
         return True
 
-
     # Helpers
+
     def _request(self, action='GET',  url='/', data=None, query_params=None):
         if data is None:
             data = {}
@@ -119,10 +127,12 @@ class Provider(BaseProvider):
             query_params = {}
         r = requests.request(action, self.api_endpoint + url, params=query_params,
                              data=json.dumps(data),
-                             auth=requests.auth.HTTPBasicAuth(self._get_provider_option('auth_username'), self._get_provider_option('auth_token')),
+                             auth=requests.auth.HTTPBasicAuth(self._get_provider_option(
+                                 'auth_username'), self._get_provider_option('auth_token')),
                              headers={
                                  'Content-Type': 'application/json',
                                  'Accept': 'application/json'
                              })
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
