@@ -1,18 +1,19 @@
 from __future__ import absolute_import
-
 import logging
 from xml.etree import ElementTree
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['namesilo.com']
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-token", help="specify key for authentication")
+    subparser.add_argument(
+        "--auth-token", help="specify key for authentication")
 
 
 class Provider(BaseProvider):
@@ -20,15 +21,16 @@ class Provider(BaseProvider):
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
-        self.api_endpoint = self._get_provider_option('api_endpoint') or 'https://www.namesilo.com/api'
+        self.api_endpoint = self._get_provider_option(
+            'api_endpoint') or 'https://www.namesilo.com/api'
 
     def authenticate(self):
 
         payload = self._get('/getDomainInfo', {'domain': self.domain})
         self.domain_id = self.domain
 
-
     # Create record. If record already exists with the same content, do nothing'
+
     def create_record(self, type, name, content):
         record = {
             'domain': self.domain_id,
@@ -42,9 +44,9 @@ class Provider(BaseProvider):
             payload = self._get('/dnsAddRecord', record)
         except ValueError as err:
             # noop if attempting to create record that already exists.
-            logger.debug('Ignoring error: {0}'.format(err))
+            LOGGER.debug('Ignoring error: {0}'.format(err))
 
-        logger.debug('create_record: %s', True)
+        LOGGER.debug('create_record: %s', True)
         return True
 
     # List all records. Return an empty list if no records found
@@ -68,11 +70,13 @@ class Provider(BaseProvider):
         if type:
             records = [record for record in records if record['type'] == type]
         if name:
-            records = [record for record in records if record['name'] == self._full_name(name)]
+            records = [record for record in records if record['name']
+                       == self._full_name(name)]
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
@@ -93,7 +97,7 @@ class Provider(BaseProvider):
 
         payload = self._get('/dnsUpdateRecord', data)
 
-        logger.debug('update_record: %s', True)
+        LOGGER.debug('update_record: %s', True)
         return True
 
     # Delete an existing record.
@@ -102,7 +106,7 @@ class Provider(BaseProvider):
         data = {
             'domain': self.domain_id
         }
-        
+
         delete_record_id = []
         if not identifier:
             records = self.list_records(type, name, content)
@@ -110,17 +114,17 @@ class Provider(BaseProvider):
         else:
             delete_record_id.append(identifier)
 
-        logger.debug('delete_records: %s', delete_record_id)
-        
+        LOGGER.debug('delete_records: %s', delete_record_id)
+
         for record_id in delete_record_id:
             data['rrid'] = record_id
             payload = self._get('/dnsDeleteRecord', data)
 
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
         return True
 
-
     # Helpers
+
     def _request(self, action='GET',  url='/', data=None, query_params=None):
         if data is None:
             data = {}
@@ -129,16 +133,19 @@ class Provider(BaseProvider):
         query_params['version'] = 1
         query_params['type'] = 'xml'
         query_params['key'] = self._get_provider_option('auth_token')
-        r = requests.request(action, self.api_endpoint + url, params=query_params)
-                             #data=json.dumps(data))
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        r = requests.request(action, self.api_endpoint +
+                             url, params=query_params)
+        # data=json.dumps(data))
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         # TODO: check if the response is an error using
         tree = ElementTree.ElementTree(ElementTree.fromstring(r.content))
         root = tree.getroot()
         if root.find('reply').find('code').text == '280':
-            raise ValueError('An error occurred: {0}, {1}'.format(root.find('reply').find('detail').text, root.find('reply').find('code').text))
+            raise ValueError('An error occurred: {0}, {1}'.format(
+                root.find('reply').find('detail').text, root.find('reply').find('code').text))
         elif root.find('reply').find('code').text != '300':
-            raise Exception('An error occurred: {0}, {1}'.format(root.find('reply').find('detail').text, root.find('reply').find('code').text))
-
+            raise Exception('An error occurred: {0}, {1}'.format(
+                root.find('reply').find('detail').text, root.find('reply').find('code').text))
 
         return root
