@@ -1,19 +1,19 @@
 """Rackspace provider implementation"""
 
 from __future__ import absolute_import
-
 import json
 import logging
 import time
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['rackspacecloud.com']
 
+
 def _async_request_completed(payload):
     """Looks into an async response payload to see if the requested job has finished."""
     if payload['status'] == 'COMPLETED':
@@ -22,12 +22,19 @@ def _async_request_completed(payload):
         return True
     return False
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-account", help="specify account number for authentication")
-    subparser.add_argument("--auth-username", help="specify username for authentication. Only used if --auth-token is empty.")
-    subparser.add_argument("--auth-api-key", help="specify api key for authentication. Only used if --auth-token is empty.")
-    subparser.add_argument("--auth-token", help="specify token for authentication. If empty, the username and api key will be used to create a token.")
-    subparser.add_argument("--sleep-time", type=float, default=1, help="number of seconds to wait between update requests.")
+    subparser.add_argument(
+        "--auth-account", help="specify account number for authentication")
+    subparser.add_argument(
+        "--auth-username", help="specify username for authentication. Only used if --auth-token is empty.")
+    subparser.add_argument(
+        "--auth-api-key", help="specify api key for authentication. Only used if --auth-token is empty.")
+    subparser.add_argument(
+        "--auth-token", help="specify token for authentication. If empty, the username and api key will be used to create a token.")
+    subparser.add_argument("--sleep-time", type=float, default=1,
+                           help="number of seconds to wait between update requests.")
+
 
 class Provider(BaseProvider):
 
@@ -61,22 +68,24 @@ class Provider(BaseProvider):
 
         self.domain_id = payload['domains'][0]['id']
 
-
     # Create record. If record already exists with the same content, do nothing'
+
     def create_record(self, type, name, content):
-        data = {'records': [{'type': type, 'name': self._full_name(name), 'data': content}]}
+        data = {'records': [
+            {'type': type, 'name': self._full_name(name), 'data': content}]}
         if self._get_lexicon_option('ttl'):
             data['records'][0]['ttl'] = self._get_lexicon_option('ttl')
 
         try:
-            payload = self._post_and_wait('/domains/{0}/records'.format(self.domain_id), data)
+            payload = self._post_and_wait(
+                '/domains/{0}/records'.format(self.domain_id), data)
         except Exception as e:
             if str(e).startswith('Record is a duplicate of another record'):
                 return self.update_record(None, type, name, content)
             raise e
 
         success = len(payload['records']) > 0
-        logger.debug('create_record: %s', success)
+        LOGGER.debug('create_record: %s', success)
         return success
 
     # List all records. Return an empty list if no records found
@@ -92,11 +101,13 @@ class Provider(BaseProvider):
         # if content:
         #     params['data'] = content
 
-        payload = self._get('/domains/{0}/records'.format(self.domain_id), params)
+        payload = self._get(
+            '/domains/{0}/records'.format(self.domain_id), params)
 
         records = list(payload['records'])
         if content:
-            records = [record for record in records if record['data'] == content]
+            records = [
+                record for record in records if record['data'] == content]
         records = [{
             'type': record['type'],
             'name': record['name'],
@@ -105,7 +116,7 @@ class Provider(BaseProvider):
             'id': record['id']
         } for record in records]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
@@ -126,10 +137,11 @@ class Provider(BaseProvider):
                 raise Exception('Unable to find record to modify: ' + name)
             identifier = records[0]['id']
 
-        self._put_and_wait('/domains/{0}/records/{1}'.format(self.domain_id, identifier), data)
+        self._put_and_wait(
+            '/domains/{0}/records/{1}'.format(self.domain_id, identifier), data)
 
         # If it didn't raise from the http status code, then we're good
-        logger.debug('update_record: %s', identifier)
+        LOGGER.debug('update_record: %s', identifier)
         return True
 
     # Delete an existing record.
@@ -142,7 +154,7 @@ class Provider(BaseProvider):
         else:
             delete_record_id.append(identifier)
 
-        logger.debug('delete_records: %s', delete_record_id)
+        LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
             payload = self._delete_and_wait(
@@ -151,24 +163,26 @@ class Provider(BaseProvider):
 
         # If it didn't raise from the http status code, then we're good
         success = True
-        logger.debug('delete_record: %s', success)
+        LOGGER.debug('delete_record: %s', success)
         return success
 
-
     # Helpers
+
     def _request(self, action='GET', url='/', data=None, query_params=None):
         if data is None:
             data = {}
         if query_params is None:
             query_params = {}
-        full_url = (self.api_endpoint + '/{0}' + url).format(self._get_provider_option('auth_account'))
+        full_url = (self.api_endpoint +
+                    '/{0}' + url).format(self._get_provider_option('auth_account'))
         r = requests.request(action, full_url, params=query_params,
                              data=json.dumps(data),
                              headers={
                                  'X-Auth-Token': self._get_provider_option('auth_token'),
                                  'Content-Type': 'application/json'
                              })
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
 
     # Non-GET requests to the Rackspace CloudDNS API are asynchronous
@@ -205,9 +219,10 @@ class Provider(BaseProvider):
                              headers={
                                  'X-Auth-Token': self._get_provider_option('auth_token'),
                                  'Content-Type': 'application/json'
-                             })
+        })
 
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
 
     def _auth_request(self, action='GET', url='/', data=None, query_params=None):
@@ -219,5 +234,6 @@ class Provider(BaseProvider):
                              headers={
                                  'Content-Type': 'application/json'
                              })
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
